# Player and Player-like objects

from erdslangetjie.data import load_image


class GameSprite(object):

    def __init__(self):
        self.pos = (0, 0)
        self.sprite = None

    def get_image(self):
        return self.sprite

    def get_texture(self):
        return self.sprite.texture


class FigureSprite(GameSprite):

    def can_move(self, direction, level):
        '''Check if we can move in the given direction'''
        cand_pos = (self.pos[0] + direction[0], self.pos[1] + direction[1])
        return not level.blocked(cand_pos)


class ThePlayer(FigureSprite):

    def __init__(self):
        super(ThePlayer, self).__init__()
        self.sprite = load_image('sprites/player.png')

    def move(self, direction, level):
        if self.can_move(direction, level):
            self.pos = (self.pos[0] + direction[0], self.pos[1] + direction[1])
            return True
        return False


class Nemesis(FigureSprite):

    def __init__(self):
        super(Nemesis, self).__init__()
        self.sprite = load_image('sprites/nemesis.png')
        self.reset_pos()

    def move(self, level):
        if not self.on_board():
            # Advance towards the map a step at a time
            self.pos = (self.pos[0] + 1, self.pos[1])
            if self.on_board():
                self.pos = level.enter_pos
            return False
        # AI goes here
        return True

    def reset_pos(self):
        self.pos = (-10, 0)

    def on_board(self):
        return self.pos[0] >= 0
